<?php
/**
 * Korpo Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Korpo Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function korpo_pro_custom_colors_css() {
  	$options= korpo_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	## Background Color
	--------------------------------------------------------------*/
	.section-subtitle:after,
	.each-faq.open h4:before,
	.btn-primary,
	input[type="submit"],
	.backtotop,
	.page-site-header .page-subtitle:after,
	#secondary .widget-title:after,
	#secondary .widgettitle:after,
	.single .page-site-header .entry-meta:after,
	#comments .comments-title:after,
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	.pagination .page-numbers.prev:hover,
	.pagination .page-numbers.next:hover,
	.pagination .page-numbers.prev:focus,
	.pagination .page-numbers.next:focus,
	.sd-title:before,
	#respond input[type="submit"],
	.blog-posts-wrapper article.hentry.sticky .entry-container .more-link .btn-primary {
		background-color: '. esc_attr( $color_value ) .';
	}

	@media screen and (min-width: 1024px) {
		.classic-menu .main-navigation ul.sub-menu li:hover > a,
		.classic-menu .main-navigation ul.sub-menu li:focus > a {
			background-color: '. esc_attr( $color_value ) .';
		}
	}

	/*--------------------------------------------------------------
	## Text Color
	--------------------------------------------------------------*/
	.site-title a:hover,
	.main-navigation ul#primary-menu li.current-menu-item > a, 
	.main-navigation ul#primary-menu li:hover > a, 
	.main-navigation ul#primary-menu li:focus > a,
	.main-navigation a:hover, 
	.main-navigation a:focus, 
	.main-navigation ul.nav-menu > li > a:hover, 
	.main-navigation ul.nav-menu > li > a:focus,
	.each-faq h4:hover,
	.project-slider article .project-content-wrapper .entry-header .entry-title a:hover,
	.post-categories a:hover,
	.post-categories a:focus,
	#latest-posts .entry-title a:hover,
	.cat-links a:hover,
	.cat-links a:focus,
	.posted-on a:hover,
	.posted-on a:focus,
	.posted-on a time:hover,
	.posted-on a time:focus,
	#colophon a:hover,
	#colophon p:hover,
	#colophon li:hover,
	.trail-items li span,
	.trail-items li a span:hover,
	.blog-posts-wrapper .entry-title a:hover,
	.widget_popular_post h3 a:hover,
	.widget_popular_post h3 a:focus,
	.widget_popular_post a:hover time,
	.widget_popular_post a:focus time,
	.widget_latest_post h3 a:hover,
	.widget_latest_post h3 a:focus,
	.widget_latest_post a:hover time,
	.widget_latest_post a:focus time,
	.blog-posts-wrapper .entry-title a:hover,
	.blog-posts-wrapper .entry-title a:focus,
	.widget.widget_categories ul li a:hover,
	.widget.widget_categories ul li a:focus,
	.tagcloud a:hover,
	.tagcloud a:focus,
	.blog-posts-wrapper.non-sticky .entry-container .more-link .btn-primary,
	.single .page-site-header .posted-on time:hover,
	.single .page-site-header .cat-links a:hover,
	.single-post-wrapper .entry-meta span.byline a:hover,
	.post-navigation a:hover span,
	.reply a,
	.comment-meta .url:hover,
	.comment-meta .url:focus,
	.comment-metadata a,
	#contact-us ul.contact-address li a:hover,
	.comment-metadata a time,
	.blog-posts-wrapper article.hentry .entry-container .more-link a.btn-primary,
	.logged-in-as a,
	.comment-content a,
	.modern-menu .main-navigation ul#primary-menu ul li:hover > a:hover,
	.modern-menu .main-navigation ul#primary-menu ul li a:hover,
	.main-navigation ul#primary-menu ul li:focus > a,
	.modern-menu .main-navigation ul#primary-menu ul li:hover > a,
	#secondary .widget a:hover  {
	    color: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Svg Color
	--------------------------------------------------------------*/
	.main-navigation ul#primary-menu li:hover > svg,
	.main-navigation ul#primary-menu li:focus > svg,
	.main-navigation li.menu-item-has-children:hover > a > svg,
	.main-navigation li.menu-item-has-children > a:hover > svg,
	.main-navigation li.menu-item-has-children > a:focus > svg,
	.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:hover svg,
	.loader-container svg {
		fill: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Border Color
	--------------------------------------------------------------*/
	.tagcloud a:hover,
	.tagcloud a:focus {
		border-color: '. esc_attr( $color_value ) .';
	}';

	/**
	 * Filters Korpo Pro custom colors CSS.
	 *
	 * @since Korpo Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'korpo_pro_custom_colors_css', $css );
}
