<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'korpo_pro_about_section', array(
	'title'             => esc_html__( 'About Us','korpo-pro' ),
	'description'       => esc_html__( 'About Section options.', 'korpo-pro' ),
	'panel'             => 'korpo_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'korpo_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Pro_Switch_Control( $wp_customize, 'korpo_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'korpo-pro' ),
	'section'           => 'korpo_pro_about_section',
	'on_off_label' 		=> korpo_pro_switch_options(),
) ) );

// About us title setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_about_section',
	'active_callback' 	=> 'korpo_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us .about-section-wrapper span.section-subtitle',
		'settings'            => 'korpo_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_about_sub_title_partial',
    ) );
}

// About us layout type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[about_layout]', array(
	'default'          	=> $options['about_layout'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_layout]', array(
	'label'             => esc_html__( 'Layout', 'korpo-pro' ),
	'section'           => 'korpo_pro_about_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'korpo_pro_is_about_section_enable',
	'choices'			=> array( 
		'image-left' 	=> esc_html__( 'Image Left', 'korpo-pro' ),
		'image-right' 	=> esc_html__( 'Image Right', 'korpo-pro' ),
	),
) );

// About us content type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'korpo-pro' ),
	'section'           => 'korpo_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'korpo_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'korpo-pro' ),
		'post' 		=> esc_html__( 'Post', 'korpo-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'korpo-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'korpo_pro_sanitize_page',
) );

$wp_customize->add_control( new Korpo_Pro_Dropdown_Chooser( $wp_customize, 'korpo_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'korpo-pro' ),
	'section'           => 'korpo_pro_about_section',
	'choices'			=> korpo_pro_page_choices(),
	'active_callback'	=> 'korpo_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'korpo_pro_sanitize_page',
) );

$wp_customize->add_control( new Korpo_Pro_Dropdown_Chooser( $wp_customize, 'korpo_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'korpo-pro' ),
	'section'           => 'korpo_pro_about_section',
	'choices'			=> korpo_pro_post_choices(),
	'active_callback'	=> 'korpo_pro_is_about_section_content_post_enable',
) ) );

// About us title setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_about_section',
	'active_callback' 	=> 'korpo_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .about-section-wrapper h2.section-title',
		'settings'            => 'korpo_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_about_title_partial',
    ) );
}

// About us description setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_about_section',
	'active_callback' 	=> 'korpo_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .about-section-wrapper .section-content p',
		'settings'            => 'korpo_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_about_description_partial',
    ) );
}

// about Section background setting and control.
$wp_customize->add_setting( 'korpo_pro_theme_options[about_image]', array(
	'default'           => $options['about_image'],
	'sanitize_callback' => 'korpo_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'korpo_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'korpo-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'korpo-pro' ), 800, 800 ),
		'section'     		=> 'korpo_pro_about_section',
		'active_callback'	=> 'korpo_pro_is_about_section_content_custom_enable',
) ) );

// About btn link setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[about_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_link]', array(
	'label'           	=> esc_html__( 'Link', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_about_section',
	'active_callback' 	=> 'korpo_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// About button setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[about_btn_label]', array(
	'default'           => $options['about_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[about_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_about_section',
	'active_callback' 	=> 'korpo_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[about_btn_label]', array(
		'selector'            => '#about-us .about-section-wrapper .entry-container .more-link a',
		'settings'            => 'korpo_pro_theme_options[about_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_about_btn_label_partial',
    ) );
}