<?php
/**
 * Project Section options
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */

// Add Project section
$wp_customize->add_section( 'korpo_pro_project_section', array(
	'title'             => esc_html__( 'Projects','korpo-pro' ),
	'description'       => esc_html__( 'Project Section options.', 'korpo-pro' ),
	'panel'             => 'korpo_pro_front_page_panel',
) );

// Project content enable control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[project_section_enable]', array(
	'default'			=> 	$options['project_section_enable'],
	'sanitize_callback' => 'korpo_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Pro_Switch_Control( $wp_customize, 'korpo_pro_theme_options[project_section_enable]', array(
	'label'             => esc_html__( 'Project Section Enable', 'korpo-pro' ),
	'section'           => 'korpo_pro_project_section',
	'on_off_label' 		=> korpo_pro_switch_options(),
) ) );

// Project title setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[project_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['project_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[project_title]', array(
	'label'           	=> esc_html__( 'Title', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_project_section',
	'active_callback' 	=> 'korpo_pro_is_project_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[project_title]', array(
		'selector'            => '#our-projects .projects-section-wrapper .entry-container .section-header span.section-subtitle',
		'settings'            => 'korpo_pro_theme_options[project_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_project_title_partial',
    ) );
}

// Project btn label setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[project_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['project_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[project_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_project_section',
	'active_callback' 	=> 'korpo_pro_is_project_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[project_btn_label]', array(
		'selector'            => '#our-projects .projects-section-wrapper .more-link a',
		'settings'            => 'korpo_pro_theme_options[project_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_project_btn_label_partial',
    ) );
}

// Project btn link setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[project_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[project_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_project_section',
	'active_callback' 	=> 'korpo_pro_is_project_section_enable',
	'type'				=> 'url',
) );

// project Section background setting and control.
$wp_customize->add_setting( 'korpo_pro_theme_options[project_image]', array(
	'default'           => $options['project_image'],
	'sanitize_callback' => 'korpo_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'korpo_pro_theme_options[project_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'korpo-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'korpo-pro' ), 800, 800 ),
		'section'     		=> 'korpo_pro_project_section',
		'active_callback'	=> 'korpo_pro_is_project_section_enable',
) ) );

// Project posts number control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[project_count]', array(
	'default'          	=> $options['project_count'],
	'sanitize_callback' => 'korpo_pro_sanitize_number_range',
	'validate_callback' => 'korpo_pro_validate_project_count',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[project_count]', array(
	'label'             => esc_html__( 'Number of Project Posts', 'korpo-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'korpo-pro' ),
	'section'           => 'korpo_pro_project_section',
	'active_callback'   => 'korpo_pro_is_project_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) ); 

// Project layout type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[project_layout]', array(
	'default'          	=> $options['project_layout'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[project_layout]', array(
	'label'             => esc_html__( 'Layout', 'korpo-pro' ),
	'section'           => 'korpo_pro_project_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'korpo_pro_is_project_section_enable',
	'choices'			=> array( 
		'image-left' 	=> esc_html__( 'Image Left', 'korpo-pro' ),
		'image-right' 	=> esc_html__( 'Image Right', 'korpo-pro' ),
	),
) );

// Project content type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[project_content_type]', array(
	'default'          	=> $options['project_content_type'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[project_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'korpo-pro' ),
	'section'           => 'korpo_pro_project_section',
	'type'				=> 'select',
	'active_callback' 	=> 'korpo_pro_is_project_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'korpo-pro' ),
		'post' 		=> esc_html__( 'Post', 'korpo-pro' ),
		'category' 	=> esc_html__( 'Category', 'korpo-pro' ),
	),
) );

for ( $i = 1; $i <= $options['project_count']; $i++ ) :

	// project pages drop down chooser control and setting
	$wp_customize->add_setting( 'korpo_pro_theme_options[project_content_page_' . $i . ']', array(
		'sanitize_callback' => 'korpo_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Korpo_Pro_Dropdown_Chooser( $wp_customize, 'korpo_pro_theme_options[project_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'korpo-pro' ), $i ),
		'section'           => 'korpo_pro_project_section',
		'choices'			=> korpo_pro_page_choices(),
		'active_callback'	=> 'korpo_pro_is_project_section_content_page_enable',
	) ) );

	// project posts drop down chooser control and setting
	$wp_customize->add_setting( 'korpo_pro_theme_options[project_content_post_' . $i . ']', array(
		'sanitize_callback' => 'korpo_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Korpo_Pro_Dropdown_Chooser( $wp_customize, 'korpo_pro_theme_options[project_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'korpo-pro' ), $i ),
		'section'           => 'korpo_pro_project_section',
		'choices'			=> korpo_pro_post_choices(),
		'active_callback'	=> 'korpo_pro_is_project_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'korpo_pro_theme_options[project_content_category]', array(
	'sanitize_callback' => 'korpo_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Korpo_Pro_Dropdown_Taxonomies_Control( $wp_customize,'korpo_pro_theme_options[project_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'korpo-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'korpo-pro' ),
	'section'           => 'korpo_pro_project_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'korpo_pro_is_project_section_content_category_enable'
) ) );
