<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */
if ( ! function_exists( 'korpo_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Korpo Pro 1.0.0
    */
    function korpo_pro_add_about_section() {
    	$options = korpo_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'korpo_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        korpo_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Korpo Pro 1.0.0
    * @param array $input about section details.
    */
    function korpo_pro_get_about_section_details( $input ) {
        $options = korpo_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']      	= ! empty( $options['about_image'] ) ? $options['about_image'] : '';
                $custom['url']          = ! empty( $options['about_link'] ) ? $options['about_link'] : '#.';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => absint( $page_id ),
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => absint( $post_id ),
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;  
        }

        if ( in_array( $about_content_type, array( 'post', 'page' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = korpo_pro_trim_content( 35 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'korpo_pro_filter_about_section_details', 'korpo_pro_get_about_section_details' );


if ( ! function_exists( 'korpo_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Korpo Pro 1.0.0
   *
   */
   function korpo_pro_render_about_section( $content_details = array() ) {
        $options = korpo_pro_get_theme_options();
        $about_sub_title = ! empty( $options['about_sub_title'] ) ? $options['about_sub_title'] : '';
        $about_btn_label = ! empty( $options['about_btn_label'] ) ? $options['about_btn_label'] : '';
        $class = ! empty( $options['about_layout'] ) ? $options['about_layout'] : 'image-left';

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : 
            $class .= ! empty( $content['image'] ) ? ' has-featured-image' : ' no-featured-image'; ?>
            <section id="about-us">
                <div class="about-section-wrapper <?php echo esc_attr( $class ); ?>">
                    <?php if ( ! empty( $content['image'] ) ) : ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                    <div class="entry-container">
                        <div class="section-header">
                            <?php if ( ! empty( $about_sub_title ) ) : ?>
                                <span class="section-subtitle"><?php echo esc_html( $about_sub_title ); ?></span>
                            <?php endif; 

                            if ( ! empty( $content['title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->

                        <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                            <div class="section-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .section-content -->
                        <?php endif; 

                        if ( ! empty( $about_btn_label ) ) : ?>
                            <div class="more-link">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $about_btn_label ); ?></a>
                            </div><!-- .more-link -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </div>
            </section><!-- #about-us -->
        <?php endforeach;
    }
endif;