<?php
/**
 * Latest section
 *
 * This is the template for the content of latest section
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */
if ( ! function_exists( 'korpo_pro_add_latest_section' ) ) :
    /**
    * Add latest section
    *
    *@since Korpo Pro 1.0.0
    */
    function korpo_pro_add_latest_section() {
    	$options = korpo_pro_get_theme_options();
        // Check if latest is enabled on frontpage
        $latest_enable = apply_filters( 'korpo_pro_section_status', true, 'latest_section_enable' );

        if ( true !== $latest_enable ) {
            return false;
        }
        // Get latest section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_pro_filter_latest_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest section now.
        korpo_pro_render_latest_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_pro_get_latest_section_details' ) ) :
    /**
    * latest section details.
    *
    * @since Korpo Pro 1.0.0
    * @param array $input latest section details.
    */
    function korpo_pro_get_latest_section_details( $input ) {
        $options = korpo_pro_get_theme_options();

        // Content type.
        $latest_content_type  = $options['latest_content_type'];
        $latest_count = ! empty( $options['latest_count'] ) ? $options['latest_count'] : 4;
        $content = array();
        switch ( $latest_content_type ) {
        	
            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $latest_count; $i++ ) {
                    if ( ! empty( $options['latest_content_post_' . $i] ) )
                        $post_ids[] = $options['latest_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $latest_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['latest_content_category'] ) ? $options['latest_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $latest_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;


            case 'recent':
                $cat_ids = ! empty( $options['latest_exclude_category'] ) ? ( array ) $options['latest_exclude_category'] : array();
                
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $latest_count ),
                    'ignore_sticky_posts'   => true,
                    'category__not_in'      => ( array ) $cat_ids,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = get_the_excerpt();
                    $page_post['date']      = get_the_date();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest section content details.
add_filter( 'korpo_pro_filter_latest_section_details', 'korpo_pro_get_latest_section_details' );


if ( ! function_exists( 'korpo_pro_render_latest_section' ) ) :
  /**
   * Start latest section
   *
   * @return string latest content
   * @since Korpo Pro 1.0.0
   *
   */
   function korpo_pro_render_latest_section( $content_details = array() ) {
        $options = korpo_pro_get_theme_options();
        $title = ! empty( $options['latest_title'] ) ? $options['latest_title'] : '';
        $btn_label = ! empty( $options['latest_btn_label'] ) ? $options['latest_btn_label'] : '';
        $btn_link = ! empty( $options['latest_btn_link'] ) ? $options['latest_btn_link'] : '#.';
        $background = ! empty( $options['latest_image'] ) ? $options['latest_image'] : '';
        $slider_direction = ! empty( $options['latest_slider_direction'] ) ? $options['latest_slider_direction'] : 'horizontal';
        $vertical = ( 'vertical' == $slider_direction ) ? 'true' : 'false';
        $vertical_arrow = ( 'vertical' == $slider_direction ) ? 'vertical-arrow' : '';
        $class = ! empty( $options['latest_layout'] ) ? $options['latest_layout'] : 'image-right';
        $class .= ! empty( $background ) ? ' has-featured-image' : ' no-featured-image';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="latest-posts">
            <div class="posts-section-wrapper <?php echo esc_attr( $class ); ?>">
                <div class="featured-image" 
                <?php if ( ! empty( $background ) ) : ?>
                    style="background-image: url('<?php echo esc_url( $background ); ?>');"
                <?php endif; ?>
                >
                    <div class="overlay"></div>
                    <?php if ( ! empty( $btn_label ) ) : ?>
                        <div class="more-link">
                            <a href="<?php echo esc_url( $btn_link ) ?>" class="btn btn-primary"><?php echo esc_html( $btn_label ); ?></a>
                        </div><!-- .more-link -->
                    <?php endif; ?>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <?php if ( ! empty( $title ) ) : ?>
                        <div class="section-header">
                            <span class="section-subtitle"><?php echo esc_html( $title ); ?></span>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content">
                        <!-- use vertical-arrow class for vertical.. -->
                        <div class="post-slider <?php echo esc_attr( $vertical_arrow ); ?>" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "fade": false, "vertical": <?php echo esc_attr( $vertical ); ?> }'>
                            <?php foreach ( $content_details as $content ) : ?>
                                <article class="slick-item">
                                    <div class="entry-meta">
                                        <?php 
                                        echo korpo_pro_categories( absint( $content['id'] ) ); 
                                        korpo_pro_posted_on( absint( $content['id'] ) ); 
                                        ?>
                                    </div><!-- .entry-meta -->  

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </article>
                            <?php endforeach; ?>
                        </div><!-- .post-slider -->
                    </div><!-- .section-content -->
                </div><!-- .entry-container -->
            </div><!-- .posts-section-wrapper -->
        </section><!-- #latest-posts -->
    <?php }
endif;